# Developper's Guide


- [The WidgetDataModel Standard](widget_data_model.md)
- [Model Types](model_types.md)
- [Reader and Writer Functions](io_provider.md)
- [Register Functions](register_functions.md)
- [Plugin System](plugin_system.md)
